@@ -50,7 +50,7 @@ If none of this works it will fall back to making _() a noop.
 #===========================================================================
 __version__ = "$Revision: 1.50 $"
 __author__ = "H. Herb <hherb@gnumed.net>, I. Haywood <i.haywood@ugrad.unimelb.edu.au>, K. Hilbert <Karsten.Hilbert@gmx.net>"
-__license__ = "GPL (details at http://www.gnu.org)"
+__license__ = "GPL v2 or later (details at http://www.gnu.org)"
 
 
 # stdlib
@@ -72,7 +72,7 @@ _substitutes_regex = regex.compile(r'%\(.+?\)s')
 # it is needed to check for successful installation of
 # the desired message catalog
 # **********************************************************
-__orig_tag__ = u'Translate this or i18n will not work properly !'
+__orig_tag__ = u'Translate this or i18n into <en_EN> will not work properly !'
 # **********************************************************
 # **********************************************************
 
@@ -196,6 +196,8 @@ def __log_locale_settings(message=None):
 					_log.debug(u'locale.nl_langinfo(%s): %s', category, unicode(locale.nl_langinfo(_nl_langinfo_categories[category]), loc_enc))
 	except:
 		_log.exception('this OS does not support nl_langinfo')
+
+	_log.debug('gmI18N.get_encoding(): %s', get_encoding())
 #---------------------------------------------------------------------------
 def _translate_protected(term):
 	"""This wraps _().
@@ -452,7 +454,7 @@ if __name__ == "__main__":
 	# it is needed to check for successful installation of
 	# the desired message catalog
 	# ********************************************************
-	tmp = _('Translate this or i18n will not work properly !')
+	tmp = _('Translate this or i18n into <en_EN> will not work properly !')
 	# ********************************************************
 	# ********************************************************
 
